@@ -14,9 +14,12 @@
 # limitations under the License.
 #
 import time
-from typing import IO
+from typing import Sequence
 
 import addonfactory_splunk_conf_parser_lib as conf_parser
+from splunk_add_on_ucc_framework import app_manifest as app_manifest_lib
+
+APP_CONF_FILE_NAME = "app.conf"
 
 
 class AppConf:
@@ -26,7 +29,12 @@ class AppConf:
     def read(self, path: str) -> None:
         self._app_conf.read(path)
 
-    def update(self, version: str, name: str, description: str, title: str) -> None:
+    def update(
+        self,
+        version: str,
+        app_manifest: app_manifest_lib.AppManifest,
+        conf_file_names: Sequence[str],
+    ) -> None:
         if "launcher" not in self._app_conf:
             self._app_conf.add_section("launcher")
         if "id" not in self._app_conf:
@@ -37,13 +45,25 @@ class AppConf:
             self._app_conf.add_section("package")
         if "ui" not in self._app_conf:
             self._app_conf.add_section("ui")
+        if "triggers" not in self._app_conf and conf_file_names:
+            self._app_conf.add_section("triggers")
 
         self._app_conf["launcher"]["version"] = version
-        self._app_conf["launcher"]["description"] = description
+        self._app_conf["launcher"]["description"] = app_manifest.get_description()
+        authors = app_manifest.get_authors()
+        first_author = authors[0]
+        self._app_conf["launcher"]["author"] = first_author["name"]
         self._app_conf["id"]["version"] = version
+        self._app_conf["id"]["name"] = app_manifest.get_addon_name()
         self._app_conf["install"]["build"] = str(int(time.time()))
-        self._app_conf["package"]["id"] = name
-        self._app_conf["ui"]["label"] = title
+        self._app_conf["install"]["is_configured"] = "true"
+        self._app_conf["install"]["state"] = "enabled"
+        self._app_conf["package"]["id"] = app_manifest.get_addon_name()
+        self._app_conf["ui"]["label"] = app_manifest.get_title()
+        self._app_conf["ui"]["is_visible"] = "true"
+        for conf_file_name in conf_file_names:
+            self._app_conf["triggers"][f"reload.{conf_file_name}"] = "simple"
 
-    def write(self, fd: IO) -> None:
-        self._app_conf.write(fd)
+    def write(self, path: str) -> None:
+        with open(path, "w") as fd:
+            self._app_conf.write(fd)
